##  Pre-requisites
When you start using SAP LeanIX Architecture and Road Map Planning, make sure you have already built a foundation in SAP LeanIX:
  * You have built your application repository as part of the [Application Portfolio Assessment](https://help.sap.com/docs/leanix/ea/application-portfolio-assessment?locale=en-US&state=PRODUCTION&version=CLOUD "Establish transparency and governance over your as-is landscape to identify optimization opportunities and unlock further use cases.").
  * Your Applications have lifecycle data maintained - otherwise, you won’t be able to reflect Applications affected by your Initiatives in the Roadmap Report.
  * Since the logic of SAP LeanIX Architecture and Road Map Planning is closely integrated with Objectives and [Initiatives](https://help.sap.com/docs/leanix/ea/initiative-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to model initiatives. This includes best practices and applicable use cases, and common antipatterns."), you should have those Fact Sheet types already modeled, or model them now as part of your [Application Modernization](https://help.sap.com/docs/leanix/ea/application-modernization?locale=en-US&state=PRODUCTION&version=CLOUD "SAP LeanIX offers a strategic approach to modernizing outdated application portfolios, helping organizations reduce technical debt and operational costs while enhancing agility and innovation. This guide is useful for understanding how to effectively plan and execute continuous transformation tailored to specific organizational needs.") or [ERP Transformation](https://help.sap.com/docs/leanix/ea/erp-transformation?locale=en-US&state=PRODUCTION&version=CLOUD "Step-by-step guide for ERP Transformation using SAP LeanIX.") use cases.
